@@ -9,6 +9,8 @@ from .datasets import *
 from .utils import *
 from .draw_tree import *
 from .mutual_information import *
+from .plots import *
+from .load_utils import *
 
 #from .models_utils import *
 #from .guides import *
